@@ -1,6 +1,6 @@
-<?php if($flow->type == 'flow'):?>
+<?php if(isset($flow) and $flow->type == 'flow'):?>
 <?php
-$select    = html::select('navigator', $lang->workflow->navigators, '', "class='form-control'");
+$select    = html::select('navigator', $lang->workflow->navigators, $flow->navigator, "class='form-control'");
 $navigator = <<<EOT
     <tr>
       <th class='w-80px'>{$lang->workflow->navigator}</th>
